package edu.mermet.tp8.fenetres;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.beans.PropertyChangeEvent;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 *
 * @author brunomermet
 */
public class FenetreConversion extends AbstractFenetreInterne {
    private JLabel labCelsius;
	private JLabel labFarenheit;
	private JTextField champCelsius;
    private JTextField champFarenheit;
    private JButton boutonConvertir;
    private Action actionConvertir;
    private boolean celsiusAFocus;
    
    private ResourceBundle contenu = ResourceBundle.getBundle("Conversion_fr");
    
    public FenetreConversion(Action action) {
        super(action,"");
        setTitle(contenu.getString("titre"));
        
        this.setSize(new Dimension(100,50));
        this.setLayout(new GridLayout(3,1));
        
        JPanel ligneCelsius = new JPanel();
        ligneCelsius.setLayout(new FlowLayout(FlowLayout.TRAILING));
        
        labCelsius = new JLabel(contenu.getString("labCelsius")+" :");
        
        champCelsius = new JTextField(15);
        labCelsius.setLabelFor(champCelsius);
        ligneCelsius.add(labCelsius);
        ligneCelsius.add(champCelsius);
        this.add(ligneCelsius);
        celsiusAFocus = true;
        champCelsius.addFocusListener(new EcouteurFocus(true));
        JPanel ligneFarenheit = new JPanel();
        ligneFarenheit.setLayout(new FlowLayout(FlowLayout.TRAILING));
        
        labFarenheit = new JLabel(contenu.getString("labFarenheit")+" :");
        
        champFarenheit = new JTextField(15);
        labFarenheit.setLabelFor(champFarenheit);
        ligneFarenheit.add(labFarenheit);
        ligneFarenheit.add(champFarenheit);
        this.add(ligneFarenheit);
        champFarenheit.addFocusListener(new EcouteurFocus(false));
        JPanel ligneValider = new JPanel();
        ligneValider.setLayout(new FlowLayout(FlowLayout.CENTER));
        
        actionConvertir = new ActionConvertir(contenu);
        
        boutonConvertir = new JButton(actionConvertir);
        ligneValider.add(boutonConvertir);
        this.add(ligneValider);
        
        pack();
        getRootPane().setDefaultButton(boutonConvertir);
    }

    private class EcouteurFocus implements FocusListener {
        private boolean aStocker;

        public EcouteurFocus(boolean b) {
            aStocker = b;
        }

        @Override
        public void focusGained(FocusEvent fe) {
            celsiusAFocus = aStocker;
        }

        @Override
        public void focusLost(FocusEvent fe) {
            return;
        }
    }

    private class ActionConvertir extends AbstractAction {

        public ActionConvertir(ResourceBundle contenu) {
            super(contenu.getString("boutonConvertir"));
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            double tempCelsius = 0;
            double tempFarenheit = 0;
            if (celsiusAFocus) {
                try {
                    tempCelsius = Double.parseDouble(champCelsius.getText());
                tempFarenheit = 9./5*tempCelsius+32;
                champFarenheit.setText(""+tempFarenheit);
                }
                catch (NumberFormatException nfe) {
                    champFarenheit.setText("Format incorrect");
                }
            }
            else {
                try {
                    tempFarenheit = Double.parseDouble(champFarenheit.getText());
                    tempCelsius = (tempFarenheit - 32) *5./9;
                    champCelsius.setText(""+tempCelsius);
                }
                catch (NumberFormatException nfe) {
                    champCelsius.setText("Format incorrect");
                }
                
            }
        }
    }

    private void refresh() {
    	this.setTitle(contenu.getString("titre"));
    	this.labCelsius.setText(contenu.getString("labCelsius")+" :");
    	this.labFarenheit.setText(contenu.getString("labFarenheit")+" :");
    	this.boutonConvertir.setText(contenu.getString("boutonConvertir"));
    }
    
	@Override
	public void propertyChange(PropertyChangeEvent evt) {
		// TODO Auto-generated method stub
		Locale l = (Locale) evt.getNewValue();
		
		switch(l.getLanguage()) {
			case "fr" : contenu = ResourceBundle.getBundle("Conversion_fr"); break;
			case "en" : contenu = ResourceBundle.getBundle("Conversion_en"); break;
			case "ja" : contenu = ResourceBundle.getBundle("Conversion_ja"); break;
			default:    contenu = ResourceBundle.getBundle("Conversion_fr"); break;
		}
		
		refresh();
	}
    
}
